@@ -24,14 +24,13 @@
 Provide a simplified table creation interface
 """
 
-import cgi
+from html import escape
 from ..const import GRAMPS_LOCALE as glocale
 _ = glocale.translation.sgettext
 from ..lib import (Person, Family, Event, Source, Place, Citation,
                    Repository, MediaObject, Note, Date, Span)
 from ..config import config
 from ..datehandler import displayer
-from ..constfunc import STRTYPE, conv_to_unicode_direct
 
 class SimpleTable(object):
     """
@@ -70,7 +69,7 @@ class SimpleTable(object):
         """
         Set the columns
         """
-        self._columns = [conv_to_unicode_direct(col) for col in cols]
+        self._columns = [str(col) for col in cols]
         self._sort_vals = [[] for i in range(len(self._columns))]
 
     def row_sort_val(self, col, val):
@@ -100,14 +99,14 @@ class SimpleTable(object):
             # FIXME: add better text representations of these objects
             if item is None:
                 retval.append("")
-            elif isinstance(item, STRTYPE):
+            elif isinstance(item, str):
                 if item == "checkbox": 
                     retval.append(False)
                     self.set_cell_type(col, "checkbox")
                 else:
                     retval.append(item)
             elif isinstance(item, (int, float)):
-                retval.append(conv_to_unicode_direct(item))
+                retval.append(str(item))
                 self.row_sort_val(col, item)
             elif isinstance(item, bool):
                 retval.append(repr(item))
@@ -154,7 +153,7 @@ class SimpleTable(object):
                 if item.get_valid():
                     if item.format:
                         self.set_cell_markup(col, row, 
-                                             item.format % cgi.escape(text))
+                                             item.format % escape(text))
                     self.row_sort_val(col, item.sortval)
                 else:
                     # sort before others:
@@ -162,11 +161,11 @@ class SimpleTable(object):
                     # give formatted version:
                     invalid_date_format = config.get('preferences.invalid-date-format')
                     self.set_cell_markup(col, row,
-                                         invalid_date_format % cgi.escape(text))
+                                         invalid_date_format % escape(text))
                 if (self._link_col == col or link is None):
                     link = ('Date', item)
             elif isinstance(item, Span):
-                text = conv_to_unicode_direct(item)
+                text = str(item)
                 retval.append(text)
                 self.row_sort_val(col, item)
             elif isinstance(item, list): # [text, "PersonList", handle, ...]
@@ -239,7 +238,7 @@ class SimpleTable(object):
                     else:
                         doc.start_link("/%s/%s" % 
                                        (obj_type.lower(), handle))
-                doc.write_text(conv_to_unicode_direct(col), 'Normal')
+                doc.write_text(str(col), 'Normal')
                 if obj_type and handle:
                     doc.stop_link()
                 doc.end_cell()
@@ -262,7 +261,7 @@ class SimpleTable(object):
             elif y in self._cell_markup[x]:
                 return self._cell_markup[x][y]
             else:
-                return cgi.escape(data)
+                return escape(data)
         else:
             if y is None: 
                 return False # no markup for this column
