@@ -30,11 +30,7 @@ SVG document generator.
 # python modules
 #
 #-------------------------------------------------------------------------
-import sys
-if sys.version_info[0] < 3:
-    from StringIO import StringIO
-else:
-    from io import StringIO
+from io import StringIO
 
 #-------------------------------------------------------------------------
 #
@@ -87,7 +83,7 @@ class SvgDrawDoc(BaseDoc, DrawDoc):
             name = "%s.svg" % self.root
 
         try:
-            self.f = open(name,"w")
+            self.f = open(name,"w", encoding="utf-8")
         except IOError as msg:
             raise ReportError(_("Could not create %s") % name, msg)
         except:
@@ -102,9 +98,9 @@ class SvgDrawDoc(BaseDoc, DrawDoc):
             '<?xml version="1.0" encoding="UTF-8" standalone="no"?>\n'
             '<!DOCTYPE svg PUBLIC "-//W3C//DTD SVG 1.0//EN" '
             '"http://www.w3.org/TR/2001/REC-SVG-20010904/DTD/svg10.dtd">\n'
-            '<svg width="%5.2fcm" height="%5.2fcm" '
+            '<svg width="%4.2fcm" height="%4.2fcm" '
             'xmlns="http://www.w3.org/2000/svg">\n'
-            '<rect width="%5.2fcm" height="%5.2fcm" '
+            '<rect width="%4.2fcm" height="%4.2fcm" '
             'style="fill: %s;"/>\n'
                 % (width, height, width, height, self._bg)
             )
@@ -138,7 +134,7 @@ class SvgDrawDoc(BaseDoc, DrawDoc):
             self.t.write('font-weight:bold;')
         if font.get_italic():
             self.t.write('font-style:italic;')
-        self.t.write('font-size:%d; ' % size)
+        self.t.write('font-size:%dpt; ' % size)
         if font.get_type_face() == FONT_SANS_SERIF:
             self.t.write('font-family:sans-serif;')
         else:
@@ -212,12 +208,13 @@ class SvgDrawDoc(BaseDoc, DrawDoc):
 
         style_sheet = self.get_style_sheet()
         box_style = style_sheet.get_draw_style(style)
+        shadow_width = box_style.get_shadow_space()
 
-        if box_style.get_shadow():
+        if box_style.get_shadow() and shadow_width > 0:
             self.f.write(
                 '<rect ' +
-                'x="%4.2fcm" ' % (x+0.15) +
-                'y="%4.2fcm" ' % (y+0.15) +
+                'x="%4.2fcm" ' % (x + shadow_width) +
+                'y="%4.2fcm" ' % (y + shadow_width) +
                 'width="%4.2fcm" ' % w +
                 'height="%4.2fcm" ' % h +
                 'style="fill:#808080; stroke:#808080; stroke-width:1;"/>\n'
@@ -260,7 +257,7 @@ class SvgDrawDoc(BaseDoc, DrawDoc):
                     self.t.write(' font-weight:bold;')
                 if font.get_italic():
                     self.t.write(' font-style:italic;')
-                self.t.write(' font-size:%d;' % font_size)
+                self.t.write(' font-size:%dpt;' % font_size)
                 if font.get_type_face() == FONT_SANS_SERIF:
                     self.t.write(' font-family:sans-serif;')
                 else:
@@ -294,7 +291,7 @@ class SvgDrawDoc(BaseDoc, DrawDoc):
             self.t.write('font-weight:bold;')
         if font.get_italic():
             self.t.write('font-style:italic;')
-        self.t.write('font-size:%d; ' % font_size)
+        self.t.write('font-size:%dpt; ' % font_size)
         if font.get_type_face() == FONT_SANS_SERIF:
             self.t.write('font-family:sans-serif;')
         else:
