@@ -40,6 +40,8 @@ from gi.repository import Gtk
 # gramps modules
 #
 #-------------------------------------------------------------------------
+from gramps.gen.const import GRAMPS_LOCALE as glocale
+_ = glocale.translation.gettext
 from gramps.gui.utils import ProgressMeter
 from gramps.gui.plug import tool
 from gramps.gui.dialog import OkDialog
@@ -84,29 +86,29 @@ class PopulateSources(tool.Tool, ManagedWindow):
         dialog = Gtk.Dialog("Populate sources and citations tool",
                                 self.uistate.window,
                                 Gtk.DialogFlags.MODAL|Gtk.DialogFlags.DESTROY_WITH_PARENT,
-                                (Gtk.STOCK_CANCEL, Gtk.ResponseType.REJECT,
-                                 Gtk.STOCK_OK, Gtk.ResponseType.ACCEPT))
+                                (_('_Cancel'), Gtk.ResponseType.REJECT,
+                                 _('_OK'), Gtk.ResponseType.ACCEPT))
         label = Gtk.Label("Enter a valid number of sources and citations."
                           " This will create the requested number of sources,"
                           " and for each source, will create the requested"
                           " number of citations.")
         label.set_line_wrap(True)
 
-        hbox1 = Gtk.HBox()
+        hbox1 = Gtk.Box()
         label_sources = Gtk.Label(label="Number of sources" + ":")
         self.sources_entry = Gtk.Entry()
         self.sources_entry.set_text("%d" % num_sources)
         hbox1.pack_start(label_sources, False, True, 0)
         hbox1.pack_start(self.sources_entry, True, True, 0)
 
-        hbox2 = Gtk.HBox()
+        hbox2 = Gtk.Box()
         label_citations = Gtk.Label(label="Number of citations" + ":")
         self.citations_entry = Gtk.Entry()
         self.citations_entry.set_text("%d" % num_citations)
         hbox2.pack_start(label_citations, False, True, 0)
         hbox2.pack_start(self.citations_entry, True, True, 0)
         
-        vbox = Gtk.VBox()
+        vbox = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
         vbox.pack_start(label, True, True, 0)
         vbox.pack_start(hbox1, False, True, 0)
         vbox.pack_start(hbox2, False, True, 0)
