@@ -21,17 +21,28 @@
 
 #------------------------------------------------------------------------
 #
-# Gramps Modules
+# Python Modules
 #
 #------------------------------------------------------------------------
 import sys
 import time
 import re
+import base64
+import pickle
+import os
+
+#------------------------------------------------------------------------
+#
+# Gramps Modules
+#
+#------------------------------------------------------------------------
 import gramps
 from gramps.gen.lib import (Person, Family, Event, Place, Repository, 
                             Citation, Source, Note, MediaObject, Tag, 
                             Researcher)
 from gramps.gen.db import DbReadBase, DbWriteBase, DbTxn
+from gramps.gen.utils.callback import Callback
+from gramps.gen.updatecallback import UpdateCallback
 from gramps.gen.db import (PERSON_KEY,
                     FAMILY_KEY,
                     CITATION_KEY,
@@ -42,10 +53,68 @@ from gramps.gen.db import (PERSON_KEY,
                     REPOSITORY_KEY,
                     NOTE_KEY)
 from gramps.gen.utils.id import create_id
-from gramps.gen.constfunc import STRTYPE
-from gramps.webapp.libdjango import DjangoInterface
 from django.db import transaction
 
+class Environment(object):
+    """
+    Implements the Environment API.
+    """
+    def __init__(self, db):
+        self.db = db
+
+    def txn_begin(self):
+        return DjangoTxn("DbDjango Transaction", self.db)
+
+class Table(object):
+    """
+    Implements Table interface.
+    """
+    def __init__(self, funcs):
+        self.funcs = funcs
+
+    def cursor(self):
+        """
+        Returns a Cursor for this Table.
+        """
+        return self.funcs["cursor_func"]()
+
+    def put(key, data, txn=None):
+        self[key] = data
+
+class Map(dict):
+    """
+    Implements the map API for person_map, etc.
+    
+    Takes a Table() as argument.
+    """
+    def __init__(self, tbl, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.db = tbl
+
+class MetaCursor(object):
+    def __init__(self):
+        pass
+    def __enter__(self):
+        return self
+    def __iter__(self):
+        return self.__next__()
+    def __next__(self):
+        yield None
+    def __exit__(self, *args, **kwargs):
+        pass
+    def iter(self):
+        yield None
+    def first(self):
+        self._iter = self.__iter__()
+        return self.next()
+    def next(self):
+        try:
+            return next(self._iter)
+        except:
+            return None
+    def close(self):
+        pass
+
 class Cursor(object):
     def __init__(self, model, func):
         self.model = model
@@ -56,20 +125,32 @@ class Cursor(object):
         return self.__next__()
     def __next__(self):
         for item in self.model.all():
-            yield (item.handle, self.func(item.handle))
+            yield (bytes(item.handle, "utf-8"), self.func(item.handle))
     def __exit__(self, *args, **kwargs):
         pass
     def iter(self):
         for item in self.model.all():
-            yield (item.handle, self.func(item.handle))
+            yield (bytes(item.handle, "utf-8"), self.func(item.handle))
         yield None
-
-class Bookmarks:
-    def get(self):
-        return [] # handles
-    def append(self, handle):
+    def first(self):
+        self._iter = self.__iter__()
+        return self.next()
+    def next(self):
+        try:
+            return next(self._iter)
+        except:
+            return None
+    def close(self):
         pass
 
+class Bookmarks(object):
+    def __init__(self):
+        self.handles = []
+    def get(self):
+        return self.handles
+    def append(self, handle):
+        self.handles.append(handle)
+
 class DjangoTxn(DbTxn):
     def __init__(self, message, db, table=None):
         DbTxn.__init__(self, message, db)
@@ -92,14 +173,42 @@ class DjangoTxn(DbTxn):
         """
         txn[handle] = new_data
 
-class DbDjango(DbWriteBase, DbReadBase):
+    def commit(self):
+        pass
+
+class DbDjango(DbWriteBase, DbReadBase, UpdateCallback, Callback):
     """
     A Gramps Database Backend. This replicates the grampsdb functions.
     """
+    # Set up dictionary for callback signal handler
+    # ---------------------------------------------
+    # 1. Signals for primary objects
+    __signals__ = dict((obj+'-'+op, signal)
+                       for obj in
+                       ['person', 'family', 'event', 'place',
+                        'source', 'citation', 'media', 'note', 'repository', 'tag']
+                       for op, signal in zip(
+                               ['add',   'update', 'delete', 'rebuild'],
+                               [(list,), (list,),  (list,),   None]
+                       )
+                   )
+    
+    # 2. Signals for long operations
+    __signals__.update(('long-op-'+op, signal) for op, signal in zip(
+        ['start',  'heartbeat', 'end'],
+        [(object,), None,       None]
+        ))
 
-    def __init__(self):
+    # 3. Special signal for change in home person
+    __signals__['home-person-changed'] = None
+
+    # 4. Signal for change in person group name, parameters are
+    __signals__['person-groupname-rebuild'] = (str, str)
+
+    def __init__(self, directory=None):
         DbReadBase.__init__(self)
         DbWriteBase.__init__(self)
+        Callback.__init__(self)
         self._tables = {
             'Person':
                 {
@@ -194,11 +303,51 @@ class DbDjango(DbWriteBase, DbReadBase):
             }
         # skip GEDCOM cross-ref check for now:
         self.set_feature("skip-check-xref", True)
-        self.dji = DjangoInterface()
         self.readonly = False
         self.db_is_open = True
         self.name_formats = []
         self.bookmarks = Bookmarks()
+        self.undo_callback = None
+        self.redo_callback = None
+        self.undo_history_callback = None
+        self.modified   = 0
+        self.txn = DjangoTxn("DbDjango Transaction", self)
+        self.transaction = None
+        # Import cache for gedcom import, uses transactions, and
+        # two step adding of objects.
+        self.import_cache = {}
+        self.use_import_cache = False
+        self.use_db_cache = True
+        self._directory = directory
+        if directory:
+            self.load(directory)
+
+    def load(self, directory, pulse_progress=None, mode=None):
+        self._directory = directory
+        from django.conf import settings
+        default_settings = {}
+        settings_file = os.path.join(directory, "default_settings.py")
+        with open(settings_file) as f:
+            code = compile(f.read(), settings_file, 'exec')
+            exec(code, globals(), default_settings)
+
+        class Module(object):
+            def __init__(self, dictionary):
+                self.dictionary = dictionary
+            def __getattr__(self, item):
+                return self.dictionary[item]
+
+        try:
+            settings.configure(Module(default_settings))
+        except RuntimeError:
+            # already configured; ignore
+            pass
+
+        import django
+        django.setup()
+
+        from gramps.webapp.libdjango import DjangoInterface
+        self.dji = DjangoInterface()
         self.family_bookmarks = Bookmarks()
         self.event_bookmarks = Bookmarks()
         self.place_bookmarks = Bookmarks()
@@ -235,29 +384,34 @@ class DbDjango(DbWriteBase, DbReadBase):
         self.omap_index = 0
         self.rmap_index = 0
         self.nmap_index = 0
-        self.env = None
-        self.person_map = {}
-        self.family_map = {}
-        self.place_map  = {}
-        self.citation_map = {}
-        self.source_map = {}
-        self.repository_map  = {}
-        self.note_map = {}
-        self.media_map  = {}
-        self.event_map  = {}
-        self.metadata   = {}
+        self.env = Environment(self)
+        self.person_map = Map(Table(self._tables["Person"]))
+        self.family_map = Map(Table(self._tables["Family"]))
+        self.place_map  = Map(Table(self._tables["Place"]))
+        self.citation_map = Map(Table(self._tables["Citation"]))
+        self.source_map = Map(Table(self._tables["Source"]))
+        self.repository_map  = Map(Table(self._tables["Repository"]))
+        self.note_map = Map(Table(self._tables["Note"]))
+        self.media_map  = Map(Table(self._tables["Media"]))
+        self.event_map  = Map(Table(self._tables["Event"]))
+        self.tag_map  = Map(Table(self._tables["Tag"]))
+        self.metadata   = Map(Table({"cursor_func": lambda: MetaCursor()}))
         self.name_group = {}
-        self.undo_callback = None
-        self.redo_callback = None
-        self.undo_history_callback = None
-        self.modified   = 0
-        self.txn = DjangoTxn("DbDjango Transaction", self)
-        self.transaction = None
-        # Import cache for gedcom import, uses transactions, and
-        # two step adding of objects.
-        self.import_cache = {}
-        self.use_import_cache = False
-        self.use_db_cache = True
+        self.event_names = set()
+        self.individual_attributes = set()
+        self.family_attributes = set()
+        self.source_attributes = set()
+        self.child_ref_types = set()
+        self.family_rel_types = set()
+        self.event_role_names = set()
+        self.name_types = set()
+        self.origin_types = set()
+        self.repository_types = set()
+        self.note_types = set()
+        self.source_media_types = set()
+        self.url_types = set()
+        self.media_attributes = set()
+        self.place_types = set()
 
     def prepare_import(self):
         """
@@ -267,7 +421,7 @@ class DbDjango(DbWriteBase, DbReadBase):
         self.use_import_cache = True
         self.import_cache = {}
 
-    @transaction.commit_on_success
+    @transaction.atomic
     def commit_import(self):
         """
         Commits the items that were queued up during the last gedcom
@@ -326,12 +480,19 @@ class DbDjango(DbWriteBase, DbReadBase):
     def transaction_commit(self, txn):
         pass
 
-    def enable_signals(self):
-        pass
-
     def request_rebuild(self):
         # caches are ok, but let's compute public's
         self.dji.update_publics()
+        self.emit('person-rebuild')
+        self.emit('family-rebuild')
+        self.emit('place-rebuild')
+        self.emit('source-rebuild')
+        self.emit('citation-rebuild')
+        self.emit('media-rebuild')
+        self.emit('event-rebuild')
+        self.emit('repository-rebuild')
+        self.emit('note-rebuild')
+        self.emit('tag-rebuild')
 
     def get_undodb(self):
         return None
@@ -341,7 +502,7 @@ class DbDjango(DbWriteBase, DbReadBase):
 
     @staticmethod
     def _validated_id_prefix(val, default):
-        if isinstance(val, STRTYPE) and val:
+        if isinstance(val, str) and val:
             try:
                 str_ = val % 1
             except TypeError:           # missing conversion specifier
@@ -676,17 +837,6 @@ class DbDjango(DbWriteBase, DbReadBase):
             return None
         return self.make_family(family)
 
-    def get_family_from_gramps_id(self, gramps_id):
-        if self.import_cache:
-            for handle in self.import_cache:
-                if self.import_cache[handle].gramps_id == gramps_id:
-                    return self.import_cache[handle]
-        try:
-            family = self.dji.Family.get(gramps_id=gramps_id)
-        except:
-            return None
-        return self.make_family(family)
-
     def get_repository_from_handle(self, handle):
         if handle in self.import_cache:
             return self.import_cache[handle]
@@ -827,6 +977,9 @@ class DbDjango(DbWriteBase, DbReadBase):
         return self.make_media(media)
 
     def get_default_person(self):
+        people = self.dji.Person.all()
+        if people.count() > 0:
+            return self.make_person(people[0])
         return None
 
     def iter_people(self):
@@ -914,6 +1067,94 @@ class DbDjango(DbWriteBase, DbReadBase):
         else:
             return None
 
+    def get_family_from_gramps_id(self, gramps_id):
+        if self.import_cache:
+            for handle in self.import_cache:
+                if self.import_cache[handle].gramps_id == gramps_id:
+                    return self.import_cache[handle]
+        try:
+            family = self.dji.Family.get(gramps_id=gramps_id)
+        except:
+            return None
+        return self.make_family(family)
+
+    def get_source_from_gramps_id(self, gramps_id):
+        if self.import_cache:
+            for handle in self.import_cache:
+                if self.import_cache[handle].gramps_id == gramps_id:
+                    return self.import_cache[handle]
+        match_list = self.dji.Source.filter(gramps_id=gramps_id)
+        if match_list.count() > 0:
+            return self.make_source(match_list[0])
+        else:
+            return None
+
+    def get_citation_from_gramps_id(self, gramps_id):
+        if self.import_cache:
+            for handle in self.import_cache:
+                if self.import_cache[handle].gramps_id == gramps_id:
+                    return self.import_cache[handle]
+        match_list = self.dji.Citation.filter(gramps_id=gramps_id)
+        if match_list.count() > 0:
+            return self.make_citation(match_list[0])
+        else:
+            return None
+
+    def get_event_from_gramps_id(self, gramps_id):
+        if self.import_cache:
+            for handle in self.import_cache:
+                if self.import_cache[handle].gramps_id == gramps_id:
+                    return self.import_cache[handle]
+        match_list = self.dji.Event.filter(gramps_id=gramps_id)
+        if match_list.count() > 0:
+            return self.make_event(match_list[0])
+        else:
+            return None
+
+    def get_object_from_gramps_id(self, gramps_id):
+        if self.import_cache:
+            for handle in self.import_cache:
+                if self.import_cache[handle].gramps_id == gramps_id:
+                    return self.import_cache[handle]
+        match_list = self.dji.Media.filter(gramps_id=gramps_id)
+        if match_list.count() > 0:
+            return self.make_media(match_list[0])
+        else:
+            return None
+
+    def get_place_from_gramps_id(self, gramps_id):
+        if self.import_cache:
+            for handle in self.import_cache:
+                if self.import_cache[handle].gramps_id == gramps_id:
+                    return self.import_cache[handle]
+        match_list = self.dji.Place.filter(gramps_id=gramps_id)
+        if match_list.count() > 0:
+            return self.make_place(match_list[0])
+        else:
+            return None
+
+    def get_repository_from_gramps_id(self, gramps_id):
+        if self.import_cache:
+            for handle in self.import_cache:
+                if self.import_cache[handle].gramps_id == gramps_id:
+                    return self.import_cache[handle]
+        match_list = self.dji.Repsoitory.filter(gramps_id=gramps_id)
+        if match_list.count() > 0:
+            return self.make_repository(match_list[0])
+        else:
+            return None
+
+    def get_note_from_gramps_id(self, gramps_id):
+        if self.import_cache:
+            for handle in self.import_cache:
+                if self.import_cache[handle].gramps_id == gramps_id:
+                    return self.import_cache[handle]
+        match_list = self.dji.Note.filter(gramps_id=gramps_id)
+        if match_list.count() > 0:
+            return self.make_note(match_list[0])
+        else:
+            return None
+
     def get_number_of_people(self):
         return self.dji.Person.count()
 
@@ -945,34 +1186,34 @@ class DbDjango(DbWriteBase, DbReadBase):
         return self.dji.Repository.count()
 
     def get_place_cursor(self):
-        return Cursor(self.dji.Place, self.get_raw_place_data).iter()
+        return Cursor(self.dji.Place, self.get_raw_place_data)
 
     def get_person_cursor(self):
-        return Cursor(self.dji.Person, self.get_raw_person_data).iter()
+        return Cursor(self.dji.Person, self.get_raw_person_data)
 
     def get_family_cursor(self):
-        return Cursor(self.dji.Family, self.get_raw_family_data).iter()
+        return Cursor(self.dji.Family, self.get_raw_family_data)
 
     def get_event_cursor(self):
-        return Cursor(self.dji.Event, self.get_raw_event_data).iter()
+        return Cursor(self.dji.Event, self.get_raw_event_data)
 
     def get_citation_cursor(self):
-        return Cursor(self.dji.Citation, self.get_raw_citation_data).iter()
+        return Cursor(self.dji.Citation, self.get_raw_citation_data)
 
     def get_source_cursor(self):
-        return Cursor(self.dji.Source, self.get_raw_source_data).iter()
+        return Cursor(self.dji.Source, self.get_raw_source_data)
 
     def get_note_cursor(self):
-        return Cursor(self.dji.Note, self.get_raw_note_data).iter()
+        return Cursor(self.dji.Note, self.get_raw_note_data)
 
     def get_tag_cursor(self):
-        return Cursor(self.dji.Tag, self.get_raw_tag_data).iter()
+        return Cursor(self.dji.Tag, self.get_raw_tag_data)
 
     def get_repository_cursor(self):
-        return Cursor(self.dji.Repository, self.get_raw_repository_data).iter()
+        return Cursor(self.dji.Repository, self.get_raw_repository_data)
 
     def get_media_cursor(self):
-        return Cursor(self.dji.Media, self.get_raw_object_data).iter()
+        return Cursor(self.dji.Media, self.get_raw_object_data)
 
     def has_gramps_id(self, obj_key, gramps_id):
         key2table = {
@@ -1149,6 +1390,7 @@ class DbDjango(DbWriteBase, DbReadBase):
         if not person.gramps_id and set_gid:
             person.gramps_id = self.find_next_person_gramps_id()
         self.commit_person(person, trans)
+        self.emit("person-add", ([person.handle],))
         return person.handle
 
     def add_family(self, family, trans, set_gid=True):
@@ -1157,6 +1399,7 @@ class DbDjango(DbWriteBase, DbReadBase):
         if not family.gramps_id and set_gid:
             family.gramps_id = self.find_next_family_gramps_id()
         self.commit_family(family, trans)
+        self.emit("family-add", ([family.handle],))
         return family.handle
 
     def add_citation(self, citation, trans, set_gid=True):
@@ -1165,6 +1408,7 @@ class DbDjango(DbWriteBase, DbReadBase):
         if not citation.gramps_id and set_gid:
             citation.gramps_id = self.find_next_citation_gramps_id()
         self.commit_citation(citation, trans)
+        self.emit("citation-add", ([citation.handle],))
         return citation.handle
 
     def add_source(self, source, trans, set_gid=True):
@@ -1173,6 +1417,7 @@ class DbDjango(DbWriteBase, DbReadBase):
         if not source.gramps_id and set_gid:
             source.gramps_id = self.find_next_source_gramps_id()
         self.commit_source(source, trans)
+        self.emit("source-add", ([source.handle],))
         return source.handle
 
     def add_repository(self, repository, trans, set_gid=True):
@@ -1181,6 +1426,7 @@ class DbDjango(DbWriteBase, DbReadBase):
         if not repository.gramps_id and set_gid:
             repository.gramps_id = self.find_next_repository_gramps_id()
         self.commit_repository(repository, trans)
+        self.emit("repository-add", ([repository.handle],))
         return repository.handle
 
     def add_note(self, note, trans, set_gid=True):
@@ -1189,6 +1435,7 @@ class DbDjango(DbWriteBase, DbReadBase):
         if not note.gramps_id and set_gid:
             note.gramps_id = self.find_next_note_gramps_id()
         self.commit_note(note, trans)
+        self.emit("note-add", ([note.handle],))
         return note.handle
 
     def add_place(self, place, trans, set_gid=True):
@@ -1228,38 +1475,159 @@ class DbDjango(DbWriteBase, DbReadBase):
         return obj.handle
 
     def commit_person(self, person, trans, change_time=None):
-        self.import_cache[person.handle] = person
+        if self.use_import_cache:
+            self.import_cache[person.handle] = person
+        else:
+            raw = person.serialize()
+            items = self.dji.Person.filter(handle=person.handle)
+            if items.count() > 0:
+                # Hack, for the moment: delete and re-add
+                items[0].delete()
+            self.dji.add_person(person.serialize())
+            self.dji.add_person_detail(person.serialize())
+            if items.count() > 0:
+                self.emit("person-update", ([person.handle],))
+            else:
+                self.emit("person-add", ([person.handle],))
 
     def commit_family(self, family, trans, change_time=None):
-        self.import_cache[family.handle] = family
+        if self.use_import_cache:
+            self.import_cache[family.handle] = family
+        else:
+            raw = family.serialize()
+            items = self.dji.Family.filter(handle=family.handle)
+            if items.count() > 0:
+                items[0].delete()
+            self.dji.add_family(family.serialize())
+            self.dji.add_family_detail(family.serialize())
+            if items.count() > 0:
+                self.emit("family-update", ([family.handle],))
+            else:
+                self.emit("family-add", ([family.handle],))
 
     def commit_citation(self, citation, trans, change_time=None):
-        self.import_cache[citation.handle] = citation
+        if self.use_import_cache:
+            self.import_cache[citation.handle] = citation
+        else:
+            raw = citation.serialize()
+            items = self.dji.Citation.filter(handle=citation.handle)
+            if items.count() > 0:
+                items[0].delete()
+            self.dji.add_citation(citation.serialize())
+            self.dji.add_citation_detail(citation.serialize())
+            if items.count() > 0:
+                self.emit("citation-update", ([citation.handle],))
+            else:
+                self.emit("citation-add", ([citation.handle],))
 
     def commit_source(self, source, trans, change_time=None):
-        self.import_cache[source.handle] = source
+        if self.use_import_cache:
+            self.import_cache[source.handle] = source
+        else:
+            raw = source.serialize()
+            items = self.dji.Source.filter(handle=source.handle)
+            if items.count() > 0:
+                items[0].delete()
+            self.dji.add_source(source.serialize())
+            self.dji.add_source_detail(source.serialize())
+            if items.count() > 0:
+                self.emit("source-update", ([source.handle],))
+            else:
+                self.emit("source-add", ([source.handle],))
 
     def commit_repository(self, repository, trans, change_time=None):
-        self.import_cache[repository.handle] = repository
+        if self.use_import_cache:
+            self.import_cache[repository.handle] = repository
+        else:
+            raw = repository.serialize()
+            items = self.dji.Repository.filter(handle=repository.handle)
+            if items.count() > 0:
+                items[0].delete()
+            self.dji.add_repository(repository.serialize())
+            self.dji.add_repository_detail(repository.serialize())
+            if items.count() > 0:
+                self.emit("repository-update", ([repository.handle],))
+            else:
+                self.emit("repository-add", ([repository.handle],))
 
     def commit_note(self, note, trans, change_time=None):
-        self.import_cache[note.handle] = note
+        if self.use_import_cache:
+            self.import_cache[note.handle] = note
+        else:
+            raw = note.serialize()
+            items = self.dji.Note.filter(handle=note.handle)
+            if items.count() > 0:
+                items[0].delete()
+            self.dji.add_note(note.serialize())
+            self.dji.add_note_detail(note.serialize())
+            if items.count() > 0:
+                self.emit("note-update", ([note.handle],))
+            else:
+                self.emit("note-add", ([note.handle],))
 
     def commit_place(self, place, trans, change_time=None):
-        self.import_cache[place.handle] = place
+        if self.use_import_cache:
+            self.import_cache[place.handle] = place
+        else:
+            raw = place.serialize()
+            items = self.dji.Place.filter(handle=place.handle)
+            if items.count() > 0:
+                items[0].delete()
+            self.dji.add_place(place.serialize())
+            self.dji.add_place_detail(place.serialize())
+            if items.count() > 0:
+                self.emit("place-update", ([place.handle],))
+            else:
+                self.emit("place-add", ([place.handle],))
 
     def commit_event(self, event, trans, change_time=None):
-        self.import_cache[event.handle] = event
+        if self.use_import_cache:
+            self.import_cache[event.handle] = event
+        else:
+            raw = event.serialize()
+            items = self.dji.Event.filter(handle=event.handle)
+            if items.count() > 0:
+                items[0].delete()
+            self.dji.add_event(event.serialize())
+            self.dji.add_event_detail(event.serialize())
+            if items.count() > 0:
+                self.emit("event-update", ([event.handle],))
+            else:
+                self.emit("event-add", ([event.handle],))
 
     def commit_tag(self, tag, trans, change_time=None):
-        self.import_cache[tag.handle] = tag
+        if self.use_import_cache:
+            self.import_cache[tag.handle] = tag
+        else:
+            raw = tag.serialize()
+            items = self.dji.Tag.filter(handle=tag.handle)
+            if items.count() > 0:
+                items[0].delete()
+            self.dji.add_tag(tag.serialize())
+            self.dji.add_tag_detail(tag.serialize())
+            if items.count() > 0:
+                self.emit("tag-update", ([tag.handle],))
+            else:
+                self.emit("tag-add", ([tag.handle],))
 
-    def commit_media_object(self, obj, transaction, change_time=None):
+    def commit_media_object(self, media, transaction, change_time=None):
         """
         Commit the specified MediaObject to the database, storing the changes
         as part of the transaction.
         """
-        self.import_cache[obj.handle] = obj
+        if self.use_import_cache:
+            self.import_cache[obj.handle] = media
+        else:
+            raw = media.serialize()
+            items = self.dji.Media.filter(handle=media.handle)
+            if items.count() > 0:
+                items[0].delete()
+            self.dji.add_media(media.serialize())
+            self.dji.add_media_detail(media.serialize())
+            if items.count() > 0:
+                self.emit("media-update", ([media.handle],))
+            else:
+                self.emit("media-add", ([media.handle],))
 
     def get_gramps_ids(self, obj_key):
         key2table = {
@@ -1280,9 +1648,6 @@ class DbDjango(DbWriteBase, DbReadBase):
     def transaction_begin(self, transaction):
         return 
 
-    def disable_signals(self):
-        pass
-
     def set_researcher(self, owner):
         pass
 
@@ -1355,3 +1720,317 @@ class DbDjango(DbWriteBase, DbReadBase):
             return self._tables[table_name]["handle_func"](handle)
         return None
 
+    def is_empty(self):
+        """
+        Is the database empty?
+        """
+        return (self.get_number_of_people() == 0 and
+                self.get_number_of_events() == 0 and
+                self.get_number_of_places() == 0 and
+                self.get_number_of_tags() == 0 and
+                self.get_number_of_families() == 0 and
+                self.get_number_of_notes() == 0 and
+                self.get_number_of_citations() == 0 and
+                self.get_number_of_sources() == 0 and
+                self.get_number_of_media_objects() == 0 and
+                self.get_number_of_repositories() == 0)
+                
+    __callback_map = {}
+
+    def set_prefixes(self, person, media, family, source, citation,
+                     place, event, repository, note):
+        self.set_person_id_prefix(person)
+        self.set_object_id_prefix(media)
+        self.set_family_id_prefix(family)
+        self.set_source_id_prefix(source)
+        self.set_citation_id_prefix(citation)
+        self.set_place_id_prefix(place)
+        self.set_event_id_prefix(event)
+        self.set_repository_id_prefix(repository)
+        self.set_note_id_prefix(note)
+
+    def has_changed(self):
+        return False
+
+    def find_backlink_handles(self, handle, include_classes=None):
+        ## FIXME: figure out how to get objects that refer
+        ## to this handle
+        return []
+
+    def get_note_bookmarks(self):
+        return self.note_bookmarks
+
+    def get_media_bookmarks(self):
+        return self.media_bookmarks
+
+    def get_repo_bookmarks(self):
+        return self.repo_bookmarks
+
+    def get_citation_bookmarks(self):
+        return self.citation_bookmarks
+
+    def get_source_bookmarks(self):
+        return self.source_bookmarks
+
+    def get_place_bookmarks(self):
+        return self.place_bookmarks
+
+    def get_event_bookmarks(self):
+        return self.event_bookmarks
+
+    def get_bookmarks(self):
+        return self.bookmarks
+
+    def get_family_bookmarks(self):
+        return self.family_bookmarks
+
+    def get_save_path(self):
+        return "/tmp/"
+
+    ## Get types:
+    def get_event_attribute_types(self):
+        """
+        Return a list of all Attribute types assocated with Event instances
+        in the database.
+        """
+        return list(self.event_attributes)
+
+    def get_event_types(self):
+        """
+        Return a list of all event types in the database.
+        """
+        return list(self.event_names)
+
+    def get_person_event_types(self):
+        """
+        Deprecated:  Use get_event_types
+        """
+        return list(self.event_names)
+
+    def get_person_attribute_types(self):
+        """
+        Return a list of all Attribute types assocated with Person instances 
+        in the database.
+        """
+        return list(self.individual_attributes)
+
+    def get_family_attribute_types(self):
+        """
+        Return a list of all Attribute types assocated with Family instances 
+        in the database.
+        """
+        return list(self.family_attributes)
+
+    def get_family_event_types(self):
+        """
+        Deprecated:  Use get_event_types
+        """
+        return list(self.event_names)
+
+    def get_media_attribute_types(self):
+        """
+        Return a list of all Attribute types assocated with Media and MediaRef 
+        instances in the database.
+        """
+        return list(self.media_attributes)
+
+    def get_family_relation_types(self):
+        """
+        Return a list of all relationship types assocated with Family
+        instances in the database.
+        """
+        return list(self.family_rel_types)
+
+    def get_child_reference_types(self):
+        """
+        Return a list of all child reference types assocated with Family
+        instances in the database.
+        """
+        return list(self.child_ref_types)
+
+    def get_event_roles(self):
+        """
+        Return a list of all custom event role names assocated with Event
+        instances in the database.
+        """
+        return list(self.event_role_names)
+
+    def get_name_types(self):
+        """
+        Return a list of all custom names types assocated with Person
+        instances in the database.
+        """
+        return list(self.name_types)
+
+    def get_origin_types(self):
+        """
+        Return a list of all custom origin types assocated with Person/Surname
+        instances in the database.
+        """
+        return list(self.origin_types)
+
+    def get_repository_types(self):
+        """
+        Return a list of all custom repository types assocated with Repository 
+        instances in the database.
+        """
+        return list(self.repository_types)
+
+    def get_note_types(self):
+        """
+        Return a list of all custom note types assocated with Note instances 
+        in the database.
+        """
+        return list(self.note_types)
+
+    def get_source_attribute_types(self):
+        """
+        Return a list of all Attribute types assocated with Source/Citation
+        instances in the database.
+        """
+        return list(self.source_attributes)
+
+    def get_source_media_types(self):
+        """
+        Return a list of all custom source media types assocated with Source 
+        instances in the database.
+        """
+        return list(self.source_media_types)
+
+    def get_url_types(self):
+        """
+        Return a list of all custom names types assocated with Url instances 
+        in the database.
+        """
+        return list(self.url_types)
+
+    def get_place_types(self):
+        """
+        Return a list of all custom place types assocated with Place instances
+        in the database.
+        """
+        return list(self.place_types)
+
+    def get_default_handle(self):
+        people = self.dji.Person.all()
+        if people.count() > 0:
+            return people[0].handle
+        return None
+
+    def close(self):
+        pass
+
+    def get_surname_list(self):
+        return []
+
+    def is_open(self):
+        return True
+
+    def get_table_names(self):
+        """Return a list of valid table names."""
+        return list(self._tables.keys())
+
+    def find_initial_person(self):
+        return self.get_default_person()
+
+    # Removals:
+    def remove_person(self, handle, txn):
+        self.dji.Person.filter(handle=handle)[0].delete()
+        self.emit("person-delete", ([handle],))
+
+    def remove_source(self, handle, transaction):
+        self.dji.Source.filter(handle=handle)[0].delete()
+        self.emit("source-delete", ([handle],))
+
+    def remove_citation(self, handle, transaction):
+        self.dji.Citation.filter(handle=handle)[0].delete()
+        self.emit("citation-delete", ([handle],))
+
+    def remove_event(self, handle, transaction):
+        self.dji.Event.filter(handle=handle)[0].delete()
+        self.emit("event-delete", ([handle],))
+
+    def remove_object(self, handle, transaction):
+        self.dji.Media.filter(handle=handle)[0].delete()
+        self.emit("media-delete", ([handle],))
+
+    def remove_place(self, handle, transaction):
+        self.dji.Place.filter(handle=handle)[0].delete()
+        self.emit("place-delete", ([handle],))
+
+    def remove_family(self, handle, transaction):
+        self.dji.Family.filter(handle=handle)[0].delete()
+        self.emit("family-delete", ([handle],))
+
+    def remove_repository(self, handle, transaction):
+        self.dji.Repository.filter(handle=handle)[0].delete()
+        self.emit("repository-delete", ([handle],))
+
+    def remove_note(self, handle, transaction):
+        self.dji.Note.filter(handle=handle)[0].delete()
+        self.emit("note-delete", ([handle],))
+
+    def remove_tag(self, handle, transaction):
+        self.dji.Tag.filter(handle=handle)[0].delete()
+        self.emit("tag-delete", ([handle],))
+
+    def remove_from_surname_list(self, person):
+        ## FIXME
+        pass
+    
+    def get_dbname(self):
+        return "Django Database"
+
+    ## missing
+
+    def find_place_child_handles(self, handle):
+        pass
+
+    def get_cursor(self, table, txn=None, update=False, commit=False):
+        pass
+
+    def get_from_name_and_handle(self, table_name, handle):
+        """
+        Returns a gen.lib object (or None) given table_name and
+        handle.
+
+        Examples:
+
+        >>> self.get_from_name_and_handle("Person", "a7ad62365bc652387008")
+        >>> self.get_from_name_and_handle("Media", "c3434653675bcd736f23")
+        """
+        if table_name in self._tables:
+            return self._tables[table_name]["handle_func"](handle)
+        return None
+
+    def get_number_of_records(self, table):
+        pass
+
+    def get_place_parent_cursor(self):
+        pass
+
+    def get_place_tree_cursor(self):
+        pass
+
+    def get_table_metadata(self, table_name):
+        """Return the metadata for a valid table name."""
+        if table_name in self._tables:
+            return self._tables[table_name]
+        return None
+
+    def get_transaction_class(self):
+        pass
+
+    def undo(self, update_history=True):
+        # FIXME:
+        return self.undodb.undo(update_history)
+
+    def redo(self, update_history=True):
+        # FIXME:
+        return self.undodb.redo(update_history)
+
+    def backup(self):
+        pass
+
+    def restore(self):
+        pass
